@@ -1,6 +1,5 @@
 """ Token Definition """
-
-from pydantic import BaseModel
+from rowantree.contracts import BaseModel
 
 
 class Token(BaseModel):
